@@ -8,6 +8,8 @@ import werkzeug
 
 import arrow
 from flask import Flask, request, jsonify
+
+from .utils import product_provides_pricing
 from .auth import authorization_header
 from .validation import date_range_validator
 from . import constants, error_handlers, exceptions, utils
@@ -106,8 +108,10 @@ def reservation(product_id: str):
     )
 
     product_availability: Dict = utils.get_availability(product_id, day)
-    variant_quantity_map = {
-        variant['id']: variant['available_tickets']
+
+    # map variant ids to available tickets
+    variant_quantity_mapping: Dict[str, int] = {
+        str(variant['id']): variant['available_tickets']
         for variant in product_availability.get(timeslot_availability_key, {}).get('variants', [])
     }
 
@@ -115,9 +119,10 @@ def reservation(product_id: str):
     product_requires_additional_visitors_data = utils.product_required_additional_visitors_data(product_id)
 
     for ticket in tickets:
+        ticket_variant_id = str(ticket['variant_id'])
         if (
-                not variant_quantity_map.get(ticket['variant_id'])
-                or (ticket['quantity'] > variant_quantity_map.get(ticket['variant_id']))
+                not variant_quantity_mapping.get(ticket_variant_id)
+                or (ticket['quantity'] > variant_quantity_mapping.get(ticket_variant_id))
         ):
             raise exceptions.BadRequest(
                 3000,
@@ -146,12 +151,23 @@ def reservation(product_id: str):
     expires_at = arrow.utcnow().shift(minutes=30)
     reservation_date = datetime.fromisoformat(day.isoformat() + " " + timeslot)
 
-    return jsonify(
-        {
-            'reservation_id': utils.encode_reservation_id(expires_at, tickets, product_id, reservation_date),
-            'expires_at': expires_at.isoformat(),
-        }
-    )
+    reservation_response = {
+        'reservation_id': utils.encode_reservation_id(expires_at, tickets, product_id, reservation_date),
+        'expires_at': expires_at.isoformat(),
+    }
+
+    if product_provides_pricing(product_id):
+        variant_price_mapping: Dict[str, Dict] = {}  # map variant ids to price data
+        for variant in product_availability.get(timeslot_availability_key, {}).get('variants', []):
+            variant_price_mapping[variant['id']] = variant['price']
+
+        reservation_response['unit_price'] = {}
+
+        for variant_id in [str(ticket.get('variant_id')) for ticket in tickets]:
+            if variant_id in variant_price_mapping:
+                reservation_response['unit_price'][variant_id] = variant_price_mapping.get(variant_id, {})
+
+    return jsonify(reservation_response)
 
 
 @app.route('/v2/booking', methods=['POST'])
@@ -220,6 +236,13 @@ def cancel_booking(booking_id):
             'The booking cannot be cancelled, the product does not allow cancellations',
         )
 
+    if product['_tickets_already_used']:
+        raise exceptions.BadRequest(
+            3005,
+            'Tickets already used',
+            'The booking cannot be cancelled because tickets have already been used',
+        )
+
     booking_for_time = datetime.fromisoformat(booked_for).replace(tzinfo=timezone.utc)
     cancellation_time = datetime.now(timezone.utc)
     if booking_for_time < cancellation_time:
