@@ -30,6 +30,10 @@ def product_supports_timeslot(product_id: str) -> bool:
     return product_id in [p['id'] for p in PRODUCTS if p['use_timeslots']]
 
 
+def product_provides_pricing(product_id: str) -> bool:
+    return product_id in [p['id'] for p in PRODUCTS if p['provides_pricing']]
+
+
 def product_required_additional_order_data(product_id: str) -> Set[str]:
     for p in PRODUCTS:
         if p['id'] == product_id:
@@ -74,7 +78,7 @@ def get_availability(product_id: str, day: date) -> Dict:
                         "available_tickets": Int,
                         "price": {
                             "currency": "",
-                            "face_value": ""
+                            "amount": ""
                         }
                     },
                     {
@@ -83,12 +87,14 @@ def get_availability(product_id: str, day: date) -> Dict:
                         "available_tickets": Int,
                         "price": {
                             "currency": "",
-                            "face_value": ""
+                            "amount": ""
                         }
                     }
                 ]
             }
         }
+
+        The `price` attribute is optional but MUST be present if the product's `provides_pricing` is `True`.
     """
 
     timeslots = [f'{day.isoformat()}T00:00']
@@ -104,6 +110,8 @@ def get_availability(product_id: str, day: date) -> Dict:
 
     number_of_digits = 1 if day.isoweekday() % 3 == 0 else 2
 
+    product_supports_pricing = product_provides_pricing(product_id)
+
     for timeslot in timeslots:
         max_tickets = str_to_int(day.isoformat(), number_of_digits)
         tickets_left = max_tickets
@@ -120,15 +128,17 @@ def get_availability(product_id: str, day: date) -> Dict:
                 )
                 tickets_left -= variant_max_ticket
 
-            variants.append({
-                'id': str(i),
-                'name': variant,
-                'available_tickets': variant_max_ticket,
-                'price': {
-                    'face_value': f"{Decimal('12.45') * i}",
+            current_variant = {
+                'id': str(i), 'name': variant, 'available_tickets': variant_max_ticket,
+            }
+
+            if product_supports_pricing:
+                current_variant['price'] = {
+                    'amount': f"{Decimal('12.45') * i}",
                     'currency': PRODUCTS_CURRENCIES.get(product_id, 'EUR'),
-                },
-            })
+                }
+
+            variants.append(current_variant)
 
             if variant_max_ticket > timeslot_available_tickets:
                 timeslot_available_tickets = variant_max_ticket
